@@ -8,7 +8,7 @@ use crate::{into_vec::IntoVec, model::Model};
 use derive_builder::Builder;
 use serde::{Deserialize, Serialize};
 
-use super::{RequestInfo, completions};
+use super::RequestInfo;
 /// Answers questions from provided context
 ///
 /// # OpenAi documentation
@@ -142,8 +142,8 @@ pub struct Request {
 pub struct Response {
     /// the answers generated by the request
     pub answers: Vec<String>,
-    /// metadata from the completion used to create the response text
-    pub completion: completions::Response,
+    /// completion id
+    pub completion: String,
     /// the model used for the request
     pub model: String,
     /// the object / action of the request
@@ -163,8 +163,12 @@ pub struct SelectedDocument {
 }
 
 impl RequestInfo for Request {
-    type Response = Response;
     fn url(&self) -> String {
         format!("{OPENAI_URL}/answers")
     }
 }
+
+#[cfg_attr(not(feature = "blocking"), async_trait::async_trait)]
+impl crate::client::Request for Request {
+    type Response = Response;
+}
