@@ -1,19 +1,26 @@
-use serde::{Deserialize, Serialize};
-use crate::api::{Action, Auth};
+use crate::api::BuildRequest;
 use crate::OPENAI_URL;
+use serde::{Deserialize, Serialize};
 
-struct Request {
-    file_id: String,
+/// # OpenAi documentation
+///
+/// Delete a file.
+#[derive(Debug, Clone, PartialEq)]
+pub struct Request {
+    pub file_id: String,
 }
-
-impl Action for Request {
-    type Response = Response;
+impl Request {
+    pub fn new(file_id: String) -> Self {
+        Request { file_id }
+    }
+}
+impl BuildRequest for Request {
 
     fn build_request(&self, client: &crate::Client) -> crate::RequestBuilder {
         client
             .reqwest_client()
             .delete(format!("{OPENAI_URL}/files/{}", self.file_id))
-            .auth(client.gpt_token())
+            .bearer_auth(client.gpt_token())
     }
 }
 
@@ -26,3 +33,8 @@ pub struct Response {
     /// Whether the deletion was successful or not
     pub deleted: bool,
 }
+
+#[cfg_attr(not(feature = "blocking"), async_trait::async_trait)]
+impl crate::client::Request for Request {
+    type Response = Response;
+}
\ No newline at end of file
