@@ -1,22 +1,30 @@
-use serde::{Deserialize, Serialize};
-use crate::api::{Action, Auth};
+use crate::api::{BuildRequest};
+use crate::prelude::Purpose;
 use crate::OPENAI_URL;
+use serde::{Deserialize, Serialize};
 
-struct Request {
-    file_id: String,
+/// # OpenAi documentation
+///
+/// Returns information about a specific file.
+#[derive(Debug, Clone, PartialEq)]
+pub struct Request {
+    pub file_id: String,
 }
-
-impl Action for Request {
-    type Response = Response;
+impl Request {
+    pub fn new(file_id: String) -> Self {
+        Request { file_id }
+    }
+}
+impl BuildRequest for Request {
 
     fn build_request(&self, client: &crate::Client) -> crate::RequestBuilder {
         client
             .reqwest_client()
             .get(format!("{OPENAI_URL}/files/{}", self.file_id))
-            .auth(client.gpt_token())
+            .bearer_auth(client.gpt_token())
     }
 }
-#[derive(Default, Debug, Clone, PartialEq, Serialize, Deserialize)]
+#[derive(Debug, Clone, PartialEq, Serialize, Deserialize)]
 pub struct Response {
     /// The file id used to identify the file
     pub id: String,
@@ -29,5 +37,9 @@ pub struct Response {
     /// The name of the file
     pub filename: String,
     /// The purpose of the file
-    pub purpose: String,
+    pub purpose: Purpose,
 }
+#[cfg_attr(not(feature = "blocking"), async_trait::async_trait)]
+impl crate::client::Request for Request {
+    type Response = Response;
+}
\ No newline at end of file
