@@ -1,6 +1,8 @@
+use crate::api::BuildRequest;
+#[cfg(not(feature = "blocking"))]
+use async_trait::async_trait;
 use serde::de::DeserializeOwned;
 
-use crate::api::Action;
 #[cfg(not(feature = "blocking"))]
 type RequestClient = reqwest::Client;
 #[cfg(feature = "blocking")]
@@ -35,61 +37,6 @@ impl Client {
             gpt_token: token,
         }
     }
-    /// Creates a request from the passed struct
-    ///
-    /// # Usage
-    /// using a builder to build the request struct is strongly advised
-    /// # Example
-    /// ```ignore
-    /// let request = completions::Builder::default()
-    ///     .model(Model::Babbage)
-    ///     .prompt("what is 1 + 2?".into())
-    ///     .build()
-    ///     .unwrap();
-    ///
-    /// let response = client.request(request).await.unwrap();
-    /// ```
-    #[cfg(not(feature = "blocking"))]
-    pub async fn request<T>(&self, request: &T) -> reqwest::Result<T::Response>
-    where
-        T: Action,
-        T::Response: DeserializeOwned,
-    {
-        let response = request.build_request(self).send().await?;
-        let json = response.json().await?;
-        Ok(json)
-    }
-    #[cfg(feature = "blocking")]
-    pub fn request<T>(&self, request: &T) -> reqwest::Result<T::Response>
-    where
-    T: Action,
-    T::Response: DeserializeOwned,
-    {
-        let response = request.build_request(self).send()?;
-        let json = response.json()?;
-        Ok(json)
-    }
-
-    #[cfg(not(feature = "blocking"))]
-    pub async fn request_raw<T>(&self, request: &T) -> reqwest::Result<String>
-    where
-        T: Action,
-        T::Response: DeserializeOwned,
-    {
-        let response = request.build_request(self).send().await?;
-        let json = response.text().await?;
-        Ok(json)
-    }
-    #[cfg(feature = "blocking")]
-    pub fn request_raw<T>(&self, request: &T) -> reqwest::Result<String>
-    where
-        T: Action,
-        T::Response: DeserializeOwned,
-    {
-        let response = request.build_request(self).send()?;
-        let json = response.text()?;
-        Ok(json)
-    }
     /// Get a reference to the client's gpt token.
     #[must_use]
     pub fn gpt_token(&self) -> &str {
@@ -101,3 +48,59 @@ impl Client {
         &self.reqwest_client
     }
 }
+
+/// Sends the request to the OpenAi api
+///
+/// [`request`][Request::request()] returns a deserialzed version of the response,
+/// while [`request_raw`][Request::request_raw()] returns a String
+/// # Usage
+/// using a builder to build the request struct is strongly advised
+/// # Example
+/// ```ignore
+/// let request = completions::Builder::default()
+///     .model(Model::Babbage)
+///     .prompt("what is 1 + 2?".into())
+///     .build()
+///     .unwrap();
+///
+/// let response = request.request(&client).await.unwrap();
+/// ```
+#[cfg_attr(not(feature = "blocking"), async_trait)]
+pub trait Request
+where
+    Self: BuildRequest,
+    Self::Response: DeserializeOwned,
+{
+    type Response;
+    #[cfg(feature = "blocking")]
+    fn request(
+        &self,
+        client: &Client,
+    ) -> reqwest::Result<<Self as crate::client::Request>::Response> {
+        let response = self.build_request(client).send()?;
+        let json = response.json()?;
+        Ok(json)
+    }
+    #[cfg(feature = "blocking")]
+    fn request_raw(&self, client: &Client) -> reqwest::Result<String> {
+        let response = self.build_request(client).send()?;
+        let text = response.text()?;
+        Ok(text)
+    }
+
+    #[cfg(not(feature = "blocking"))]
+    async fn request(
+        &self,
+        client: &Client,
+    ) -> reqwest::Result<<Self as crate::client::Request>::Response> {
+        let response = self.build_request(client).send().await?;
+        let json = response.json().await?;
+        Ok(json)
+    }
+    #[cfg(not(feature = "blocking"))]
+    async fn request_raw(&self, client: &Client) -> reqwest::Result<String> {
+        let response = self.build_request(client).send().await?;
+        let text = response.text().await?;
+        Ok(text)
+    }
+}
